| Copyright | (c) 2018 Iris Ward |
|---|---|
| License | BSD3 |
| Maintainer | aditu.venyhandottir@gmail.com |
| Stability | experimental |
| Safe Haskell | Trustworthy |
| Language | Haskell2010 |
Data.TypeNums.Rats
Description
Type level rational numbers expressed as a ratio between a type-level integer
and a type-level natural. For example .Neg 3 :% 2
See also: Data.TypeInts
Documentation
Type constructor for a rational
This class gives the (value-level) rational associated with a type-level rational. There are instances of this class for every combination of a concrete integer and concrete natural.
Minimal complete definition
ratSing